@@ -61,7 +61,7 @@ class ToolMirrorReprepro(ToolShell):
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "",
                 "Method": "{debian_mirror}",
-                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
+                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard) | Package (== tasksel-data)",
                 "VerifyRelease": "{verify_release_keys}",
             },
             "default-udebs": {
@@ -84,7 +84,7 @@ class ToolMirrorReprepro(ToolShell):
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "",
                 "Method": "{security_mirror}",
-                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
+                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard) | Package (== tasksel-data)",
                 "VerifyRelease": "{verify_release_keys}",
             },
             "default-security": {
@@ -100,7 +100,7 @@ class ToolMirrorReprepro(ToolShell):
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "",
                 "Method": "{security_mirror}",
-                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
+                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard) | Package (== tasksel-data)",
                 "VerifyRelease": "{verify_release_keys}",
             },
             "default-updates": {
@@ -116,7 +116,7 @@ class ToolMirrorReprepro(ToolShell):
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "main",
                 "Method": "{updates_mirror}",
-                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
+                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard) | Package (== tasksel-data)",
                 "VerifyRelease": "{verify_release_keys}",
             },
             "default-extra": {
@@ -142,7 +142,7 @@ class ToolMirrorReprepro(ToolShell):
                 "Architectures": "{ARCHES}",
                 "UDebComponents": "main",
                 "Method": "{debian_mirror}",
-                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard)",
+                "FilterFormula": "priority (== required) | priority (== important) | priority (== standard) | Package (== tasksel-data)",
                 "VerifyRelease": "{verify_release_keys}",
             },
             "default-profiles-udeb": {
