@@ -40,7 +40,7 @@ VARIABLES = [
             help="pull simple-cdd-profiles udeb from specified distribution"),
     TextVar("extra_udeb_dist", cmdline="--extra-udeb-dist",
             help="pull in udebs from specified distribution"),
-    TextVar("security_mirror", "http://security.debian.org/", cmdline="--security-mirror",
+    TextVar("security_mirror", "http://security.debian.org/debian-security/", cmdline="--security-mirror",
             help="security mirror URL"),
     TextVar("backports_mirror", "{debian_mirror}", cmdline="--backports-mirror",
             help="backports mirror URL"),
